# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.



from .._models import BaseModel

__all__ = ["Agentresponse"]


class Agentresponse(BaseModel):
    task_id: str
